==> pmml-model-gwt-1.4.13.jar: org/dmg/pmml/MiningSchema.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "miningFields"
})
@XmlRootElement(name = "MiningSchema", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "extensions",
    "miningFields"
})
public class MiningSchema
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<MiningSchema>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "MiningField", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("MiningField")
    private List<MiningField> miningFields;
    private final static long serialVersionUID = 67305489L;

    public MiningSchema() {
    }

    @ValueConstructor
    public MiningSchema(
        @Property("miningFields")
        List<MiningField> miningFields) {
        this.miningFields = miningFields;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public MiningSchema addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasMiningFields() {
        return ((this.miningFields!= null)&&(this.miningFields.size()> 0));
    }

    public List<MiningField> getMiningFields() {
        if (miningFields == null) {
            miningFields = new ArrayList<MiningField>();
        }
        return this.miningFields;
    }

    public MiningSchema addMiningFields(MiningField... miningFields) {
        getMiningFields().addAll(Arrays.asList(miningFields));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasMiningFields()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getMiningFields());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.4.15.jar: org/dmg/pmml/MiningSchema.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.jpmml.model.annotations.Property;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "MiningSchema", namespace = "http://www.dmg.org/PMML-4_3")
@XmlType(name = "", propOrder = {
    "extensions",
    "miningFields"
})
@JsonRootName("MiningSchema")
@JsonPropertyOrder({
    "extensions",
    "miningFields"
})
public class MiningSchema
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<MiningSchema>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "MiningField", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    @JsonProperty("MiningField")
    private List<MiningField> miningFields;
    private final static long serialVersionUID = 67305489L;

    public MiningSchema() {
    }

    @ValueConstructor
    public MiningSchema(
        @Property("miningFields")
        List<MiningField> miningFields) {
        this.miningFields = miningFields;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public MiningSchema addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasMiningFields() {
        return ((this.miningFields!= null)&&(this.miningFields.size()> 0));
    }

    public List<MiningField> getMiningFields() {
        if (miningFields == null) {
            miningFields = new ArrayList<MiningField>();
        }
        return this.miningFields;
    }

    public MiningSchema addMiningFields(MiningField... miningFields) {
        getMiningFields().addAll(Arrays.asList(miningFields));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasMiningFields()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getMiningFields());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
